<?php
/**
 * Navigation menus and mega menu functionality.
 */
class Bunyad_Theme_Navigation
{
	public function __construct()
	{
		add_action('bunyad_theme_init', array($this, 'init'));	
	}

	public function init()
	{
		/**
		 * Navigation changes
		 */
		add_filter('bunyad_mega_menu_end_lvl', array($this, 'attach_mega_menu'));
		add_filter('wp_nav_menu_items', array($this, 'add_navigation_icons'), 10, 2);
		//add_filter('wp_nav_menu_items', array($this, 'add_navigation_logo'), 10, 2);


		add_action('wp_ajax_nopriv_bunyad_mega_menu', [$this, 'render_ajax']);
		add_action('wp_ajax_bunyad_mega_menu', [$this, 'render_ajax']);
	}

	/**
	 * Filter Callback: Add our custom mega-menus
	 *
	 * @param array $args
	 */
	public function attach_mega_menu($args)
	{
		extract($args);

		// Have a mega menu?
		if (empty($item->mega_menu)) {
			return $sub_menu;
		}
		
		ob_start();
		do_action('bunyad_mega_menu_render_before', $args);
		
		// Get our partial
		Bunyad::core()->partial('partials/mega-menu', compact('item', 'sub_menu', 'sub_items', 'args'));

		do_action('bunyad_mega_menu_render_after', $args);
		
		// Return template output
		return ob_get_clean();
	}
	

	/**
	 * Add icons for header nav-below-b
	 * 
	 * @param string $items
	 * @param object $args
	 */
	public function add_navigation_icons($items, $args)
	{
		if (!in_array(Bunyad::options()->header_layout, array('nav-below-b', 'compact')) || $args->theme_location != 'cheerup-main') {
			return $items;
		}
		
		ob_start();
		?>
		
		<li class="nav-icons">
			<div>
				<?php do_action('bunyad_header_nav_icons'); ?>

				<?php if (Bunyad::options()->header_cart_icon && class_exists('Bunyad_Theme_WooCommerce')): ?>
				
				<div class="cart-action cf">
					<?php echo Bunyad::get('woocommerce')->cart_link(); ?>
				</div>
				
				<?php endif; ?>
				
				<?php if (Bunyad::options()->topbar_search): ?>
				
				<a href="#" title="<?php esc_attr_e('Search', 'cheerup'); ?>" class="search-link"><i class="tsi tsi-search"></i></a>
				
				<div class="search-box-overlay">
					<?php
					Bunyad::helpers()->search_form('alt', array(
						'text' => esc_html__('Type and press enter', 'cheerup')
					));
					?>
				</div>
				
				<?php endif; ?>
			</div>
		</li>
		
		<?php
		
		$items .= ob_get_clean();
		
		return $items;
	}

	/**
	 * Filter callback: Add logo to the sticky navigation
	 */
	public function add_navigation_logo($items, $args)
	{
		if (!Bunyad::options()->topbar_sticky OR $args->theme_location != 'cheerup-main') {
			return $items;
		}
		
		if (Bunyad::options()->image_logo) {
			$logo = '<img src="' . esc_attr(Bunyad::options()->image_logo) .'" />'; 
		}
		
		$items = '<li class="sticky-logo"><a href="'. esc_url(home_url('/')) .'">' . $logo . '</a></li>' . $items;
		
		return $items;
	}

	/**
	 * AJAX Pagination for mega menus.
	 *
	 * @return void
	 */
	public function render_ajax()
	{
		if (!isset($_REQUEST['page']) || !isset($_REQUEST['id'])) {
			wp_die('0');
		}

		Bunyad::core()->partial('partials/mega-menu-posts', [
			'props' => [
				'id'    => intval($_REQUEST['id']),
				'page'  => intval($_REQUEST['page']),
				// Set a max posts per page limit to prevent DOS.
				'posts' => min(intval($_REQUEST['posts']), 10),
				'have_sub_menu' => $_REQUEST['submenu'] ? true : false,
			]
		]);

		wp_die();
	}
}

// init and make available in Bunyad::get('navigation')
Bunyad::register('navigation', array(
	'class' => 'Bunyad_Theme_Navigation',
	'init' => true
));